==> owncloud-8.2.2-2-any.pkg.tar.xz: usr/share/webapps/owncloud/core/l10n/ka_GE.js <==
OC.L10N.register(
    "core",
    {
    "Sunday" : "კვირა",
    "Monday" : "ორშაბათი",
    "Tuesday" : "სამშაბათი",
    "Wednesday" : "ოთხშაბათი",
    "Thursday" : "ხუთშაბათი",
    "Friday" : "პარასკევი",
    "Saturday" : "შაბათი",
    "Sun." : "კვ.",
    "Mon." : "ორშ.",
    "Tue." : "სამ.",
    "Wed." : "ოთხ.",
    "Thu." : "ხუთ.",
    "Fri." : "პარ.",
    "Sat." : "შაბ.",
    "January" : "იანვარი",
    "February" : "თებერვალი",
    "March" : "მარტი",
    "April" : "აპრილი",
    "May" : "მაისი",
    "June" : "ივნისი",
    "July" : "ივლისი",
    "August" : "აგვისტო",
    "September" : "სექტემბერი",
    "October" : "ოქტომბერი",
    "November" : "ნოემბერი",
    "December" : "დეკემბერი",
    "Jan." : "იან.",
    "Feb." : "თებ.",
    "Mar." : "მარ.",
    "Apr." : "აპრ.",
    "May." : "მაი.",
    "Jun." : "ივნ.",
    "Jul." : "ივლ.",
    "Aug." : "აგვ.",
    "Sep." : "სექ.",
    "Oct." : "ოქტ.",
    "Nov." : "ნოე.",
    "Dec." : "დეკ.",
    "Settings" : "პარამეტრები",
    "Saving..." : "შენახვა...",
    "seconds ago" : "წამის წინ",
    "No" : "არა",
    "Yes" : "კი",
    "Choose" : "არჩევა",
    "Ok" : "დიახ",
    "New Files" : "ახალი ფაილები",
    "Cancel" : "უარყოფა",
    "Shared" : "გაზიარებული",
    "Error" : "შეცდომა",
    "Error while sharing" : "შეცდომა გაზიარების დროს",
    "Error while unsharing" : "შეცდომა გაზიარების გაუქმების დროს",
    "Error while changing permissions" : "შეცდომა დაშვების ცვლილების დროს",
    "Error setting expiration date" : "შეცდომა ვადის გასვლის მითითების დროს",
    "Set expiration date" : "მიუთითე ვადის გასვლის დრო",
    "Expiration" : "ვადის გასვლის დრო",
    "Expiration date" : "ვადის გასვლის დრო",
    "Sending ..." : "გაგზავნა ....",
    "Email sent" : "იმეილი გაიგზავნა",
    "Resharing is not allowed" : "მეორეჯერ გაზიარება არ არის დაშვებული",
    "Password protect" : "პაროლით დაცვა",
    "Password" : "პაროლი",
    "Email link to person" : "ლინკის პიროვნების იმეილზე გაგზავნა",
    "Send" : "გაგზავნა",
    "Shared with you and the group {group} by {owner}" : "გაზიარდა თქვენთვის და ჯგუფისთვის {group}, {owner}–ის მიერ",
    "Shared with you by {owner}" : "გაზიარდა თქვენთვის {owner}–ის მიერ",
    "Shared in {item} with {user}" : "გაზიარდა {item}–ში  {user}–ის მიერ",
    "group" : "ჯგუფი",
    "Unshare" : "გაუზიარებადი",
    "can edit" : "შეგიძლია შეცვლა",
    "create" : "შექმნა",
    "delete" : "წაშლა",
    "access control" : "დაშვების კონტროლი",
    "Share" : "გაზიარება",
    "Warning" : "გაფრთხილება",
    "The object type is not specified." : "ობიექტის ტიპი არ არის მითითებული.",
    "Delete" : "წაშლა",
    "Add" : "დამატება",
    "The update was successful. Redirecting you to ownCloud now." : "განახლება ვერ განხორციელდა. გადამისამართება თქვენს ownCloud–ზე.",
    "Use the following link to reset your password: {link}" : "გამოიყენე შემდეგი ლინკი პაროლის შესაცვლელად: {link}",
    "New password" : "ახალი პაროლი",
    "Reset password" : "პაროლის შეცვლა",
    "Personal" : "პირადი",
    "Users" : "მომხმარებელი",
    "Apps" : "აპლიკაციები",
    "Admin" : "ადმინისტრატორი",
    "Help" : "დახმარება",
    "Access forbidden" : "წვდომა აკრძალულია",
    "Your data directory and files are probably accessible from the internet because the .htaccess file does not work." : "თქვენი data დირექტორია და ფაილები დაშვებადია ინტერნეტში რადგან  .htaccess ფაილი არ მუშაობს.",
    "Create an <strong>admin account</strong>" : "შექმენი <strong>ადმინ ექაუნტი</strong>",
    "Username" : "მომხმარებლის სახელი",
    "Data folder" : "მონაცემთა საქაღალდე",
    "Configure the database" : "მონაცემთა ბაზის კონფიგურირება",
    "Database user" : "მონაცემთა ბაზის მომხმარებელი",
    "Database password" : "მონაცემთა ბაზის პაროლი",
    "Database name" : "მონაცემთა ბაზის სახელი",
    "Database tablespace" : "ბაზის ცხრილის ზომა",
    "Database host" : "მონაცემთა ბაზის ჰოსტი",
    "Finish setup" : "კონფიგურაციის დასრულება",
    "Log out" : "გამოსვლა",
    "Search" : "ძებნა",
    "Log in" : "შესვლა",
    "remember" : "დამახსოვრება",
    "Alternative Logins" : "ალტერნატიული Login–ი"
},
"nplurals=1; plural=0;");

==> owncloud-9.1.1-1-any.pkg.tar.xz: usr/share/webapps/owncloud/core/l10n/ka_GE.js <==
OC.L10N.register(
    "core",
    {
    "Sunday" : "კვირა",
    "Monday" : "ორშაბათი",
    "Tuesday" : "სამშაბათი",
    "Wednesday" : "ოთხშაბათი",
    "Thursday" : "ხუთშაბათი",
    "Friday" : "პარასკევი",
    "Saturday" : "შაბათი",
    "Sun." : "კვ.",
    "Mon." : "ორშ.",
    "Tue." : "სამ.",
    "Wed." : "ოთხ.",
    "Thu." : "ხუთ.",
    "Fri." : "პარ.",
    "Sat." : "შაბ.",
    "January" : "იანვარი",
    "February" : "თებერვალი",
    "March" : "მარტი",
    "April" : "აპრილი",
    "May" : "მაისი",
    "June" : "ივნისი",
    "July" : "ივლისი",
    "August" : "აგვისტო",
    "September" : "სექტემბერი",
    "October" : "ოქტომბერი",
    "November" : "ნოემბერი",
    "December" : "დეკემბერი",
    "Jan." : "იან.",
    "Feb." : "თებ.",
    "Mar." : "მარ.",
    "Apr." : "აპრ.",
    "May." : "მაი.",
    "Jun." : "ივნ.",
    "Jul." : "ივლ.",
    "Aug." : "აგვ.",
    "Sep." : "სექ.",
    "Oct." : "ოქტ.",
    "Nov." : "ნოე.",
    "Dec." : "დეკ.",
    "Settings" : "პარამეტრები",
    "Saving..." : "შენახვა...",
    "seconds ago" : "წამის წინ",
    "No" : "არა",
    "Yes" : "კი",
    "Choose" : "არჩევა",
    "Ok" : "დიახ",
    "New Files" : "ახალი ფაილები",
    "Cancel" : "უარყოფა",
    "Shared" : "გაზიარებული",
    "Error" : "შეცდომა",
    "Error while sharing" : "შეცდომა გაზიარების დროს",
    "Error while unsharing" : "შეცდომა გაზიარების გაუქმების დროს",
    "Error setting expiration date" : "შეცდომა ვადის გასვლის მითითების დროს",
    "Set expiration date" : "მიუთითე ვადის გასვლის დრო",
    "Expiration" : "ვადის გასვლის დრო",
    "Expiration date" : "ვადის გასვლის დრო",
    "Resharing is not allowed" : "მეორეჯერ გაზიარება არ არის დაშვებული",
    "Password protect" : "პაროლით დაცვა",
    "Password" : "პაროლი",
    "Email link to person" : "ლინკის პიროვნების იმეილზე გაგზავნა",
    "Send" : "გაგზავნა",
    "Sending ..." : "გაგზავნა ....",
    "Email sent" : "იმეილი გაიგზავნა",
    "Shared with you and the group {group} by {owner}" : "გაზიარდა თქვენთვის და ჯგუფისთვის {group}, {owner}–ის მიერ",
    "Shared with you by {owner}" : "გაზიარდა თქვენთვის {owner}–ის მიერ",
    "group" : "ჯგუფი",
    "Unshare" : "გაუზიარებადი",
    "can edit" : "შეგიძლია შეცვლა",
    "create" : "შექმნა",
    "delete" : "წაშლა",
    "access control" : "დაშვების კონტროლი",
    "Share" : "გაზიარება",
    "Warning" : "გაფრთხილება",
    "Delete" : "წაშლა",
    "Rename" : "გადარქმევა",
    "The object type is not specified." : "ობიექტის ტიპი არ არის მითითებული.",
    "Add" : "დამატება",
    "The update was unsuccessful. Please report this issue to the <a href=\"https://github.com/owncloud/core/issues\" target=\"_blank\">ownCloud community</a>." : "განახლება ვერ განხორციელდა. გთხოვთ შეგვატყობინოთ ამ პრობლემის შესახებ აქ: <a href=\"https://github.com/owncloud/core/issues\" target=\"_blank\">ownCloud community</a>.",
    "The update was successful. Redirecting you to ownCloud now." : "განახლება ვერ განხორციელდა. გადამისამართება თქვენს ownCloud–ზე.",
    "Personal" : "პირადი",
    "Users" : "მომხმარებელი",
    "Apps" : "აპლიკაციები",
    "Admin" : "ადმინისტრატორი",
    "Help" : "დახმარება",
    "Access forbidden" : "წვდომა აკრძალულია",
    "Your data directory and files are probably accessible from the internet because the .htaccess file does not work." : "თქვენი data დირექტორია და ფაილები დაშვებადია ინტერნეტში რადგან  .htaccess ფაილი არ მუშაობს.",
    "Create an <strong>admin account</strong>" : "შექმენი <strong>ადმინ ექაუნტი</strong>",
    "Username" : "მომხმარებლის სახელი",
    "Data folder" : "მონაცემთა საქაღალდე",
    "Configure the database" : "მონაცემთა ბაზის კონფიგურირება",
    "Database user" : "მონაცემთა ბაზის მომხმარებელი",
    "Database password" : "მონაცემთა ბაზის პაროლი",
    "Database name" : "მონაცემთა ბაზის სახელი",
    "Database tablespace" : "ბაზის ცხრილის ზომა",
    "Database host" : "მონაცემთა ბაზის ჰოსტი",
    "Finish setup" : "კონფიგურაციის დასრულება",
    "Log out" : "გამოსვლა",
    "Search" : "ძებნა",
    "Log in" : "შესვლა",
    "Alternative Logins" : "ალტერნატიული Login–ი",
    "Use the following link to reset your password: {link}" : "გამოიყენე შემდეგი ლინკი პაროლის შესაცვლელად: {link}",
    "New password" : "ახალი პაროლი",
    "Reset password" : "პაროლის შეცვლა"
},
"nplurals=1; plural=0;");
